@@ -232,6 +232,10 @@ class LibraryPage(Adw.NavigationPage):
 
         self.window.navigationview.add(self)
 
+    def add_accelerators(self):
+        self.window.application.set_accels_for_action('app.library.update', ['<Primary>r'])
+        self.window.application.set_accels_for_action('app.library.toggle-categories', ['F9'])
+
     def add_actions(self):
         add_action = Gio.SimpleAction.new('add', None)
         add_action.connect('activate', self.on_left_button_clicked)
@@ -307,6 +311,15 @@ class LibraryPage(Adw.NavigationPage):
         select_all_action.connect('activate', self.select_all)
         self.window.application.add_action(select_all_action)
 
+        # Shortcuts
+        toggle_categories_action = Gio.SimpleAction.new('library.toggle-categories', None)
+        toggle_categories_action.connect(
+            'activate', lambda _action, _param: self.overlaysplitview.set_show_sidebar(
+                not self.overlaysplitview.get_show_sidebar()
+            )
+        )
+        self.window.application.add_action(toggle_categories_action)
+
     def compute_thumbnails_cover_size(self):
         default_width = Thumbnail.default_width
         default_height = Thumbnail.default_height
@@ -520,7 +533,7 @@ class LibraryPage(Adw.NavigationPage):
 
         return Gdk.EVENT_PROPAGATE
 
-    def on_manga_updated(self, _obj, manga, _result):
+    def on_manga_updated(self, _obj, manga, _chapters_changes, _synced):
         self.refresh_on_manga_state_changed(manga)
 
     def on_overlaysplitview_revealed(self, _overlaysplitview, _param):
@@ -665,13 +678,6 @@ class LibraryPage(Adw.NavigationPage):
         if self.selected_filters:
             self.flowbox.invalidate_filter()
 
-    def reinstantiate_servers(self):
-        """Used when servers modules origin change: servers variables need to be re-instantiated"""
-
-        # Clear thumbnails servers
-        for thumbnail in self.flowbox:
-            thumbnail.manga._server = None
-
     def remove_thumbnail(self, manga):
         # Remove manga thumbnail in flowbox
         thumbnail = self.flowbox.get_first_child()
