@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from komikku.servers.multi.keyoapp import Keyoapp
@@ -11,4 +11,4 @@ class Kewnscans(Keyoapp):
     lang = 'en'
 
     base_url = 'https://kewnscans.org'
-    media_url = 'https://imageserver.is1.buzz'
+    logo_url = 'https://wsrv.nl/?url=cdn.meowing.org/uploads/d4846f15ded&w=20'
