@@ -1,16 +1,43 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
-from bs4 import BeautifulSoup
+from functools import wraps
 from gettext import gettext as _
+
+from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.utils import get_buffer_mime_type
 from komikku.utils import is_number
+from komikku.webview import get_page_html
+
+
+def get_mwcookie(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        server = args[0]
+
+        found = False
+        for name, _value in server.session.cookies.items():
+            if name == 'MWCookie':
+                found = True
+                break
+
+        if not found:
+            _html, cookies = get_page_html(server.base_url, user_agent=USER_AGENT, with_cookies=True)
+
+            for cookie in cookies:
+                if cookie.name == 'MWCookie':
+                    server.session.cookies.set_cookie(cookie)
+                    break
+
+        return func(*args, **kwargs)
+
+    return wrapper
 
 
 class Mangaworld(Server):
@@ -19,7 +46,8 @@ class Mangaworld(Server):
     lang = 'it'
     is_nsfw = True
 
-    base_url = 'https://www.mangaworld.ac'
+    base_url = 'https://www.mangaworld.cx'
+    logo_url = base_url + '/public/assets/seo/favicon-32x32.png'
     search_url = base_url + '/archive'
     manga_url = base_url + '/manga/{0}'
     chapter_url = base_url + '/manga/{0}/read/{1}/1?style=list'
@@ -63,6 +91,7 @@ class Mangaworld(Server):
                 'User-Agent': USER_AGENT,
             })
 
+    @get_mwcookie
     def get_manga_data(self, initial_data):
         """
         Returns manga data by scraping manga HTML page content
@@ -135,6 +164,7 @@ class Mangaworld(Server):
 
         return data
 
+    @get_mwcookie
     def get_manga_chapter_data(self, manga_slug, manga_name, chapter_slug, chapter_url):
         """
         Returns manga chapter data by scraping chapter HTML page content
@@ -189,6 +219,7 @@ class Mangaworld(Server):
     def get_most_populars(self, types=None, statuses=None):
         return self.search('', types, statuses, orderby='populars')
 
+    @get_mwcookie
     def search(self, term, types=None, statuses=None, orderby=None):
         if orderby:
             params = {
