@@ -10,7 +10,7 @@ from komikku.servers.utils import convert_date_string
 from komikku.utils import get_buffer_mime_type
 from komikku.webview import CompleteChallenge
 
-IMAGES_EXTS = dict(g='gif', j='jpg', p='png')
+IMAGES_EXTS = dict(g='gif', j='jpg', p='png', w='webp')
 
 # Mirrors
 # https://nhentai.to
