@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from komikku.servers.multi.peachscan import Peachscan
@@ -9,7 +9,8 @@ class Wickedwitchscan(Peachscan):
     id = 'wickedwitchscan'
     name = 'Wicked Witch Scan'
     lang = 'pt_BR'
+    status = 'disabled'
 
     has_cf = True
 
-    base_url = 'https://wicked-witch-scan.com'
+    base_url = 'https://wickedscans.org'
